@@ -53,18 +53,29 @@ def _cut_legend(legend):
     Args:
         legend(str): It take the name of the legend.
     """
-    import cv2
-    file_name = legend
-    y = 85
-    h = 110
-    x = 0
-    w = 1200
+    from PIL import Image
 
-    # it load and save the new image
-    img = cv2.imread(file_name)
-    crop_img = img[y:y+h, x:x+w]
-    cv2.imwrite(file_name, crop_img)
+    # Download Image:
+    im = Image.open(legend)
 
+    # Check Image Size
+    im_size = im.size
+
+    # Define box inside image
+    left = 40
+    top = 65
+    width = 230
+    height = 61
+
+    # Create Box
+    box = (left, top, left+width, top+height)
+
+    # Crop Image
+    area = im.crop(box)
+    #area.show()
+
+    # Save Image
+    area.save(legend, "PNG")
 
 def _groups_graph(file_name):
     """
@@ -151,11 +162,11 @@ def _index_generator(file_name):
     L=[]
     for i in range(len(color)):
         L.append(i*3) #i's use for the separation between nodes
-    fig = plt.figure(1, figsize=(5, 3))
+    fig = plt.figure(1, figsize=(10, 3))
     plt.scatter(L, [1  for x in range(len(color))], s = 2000/len(L), color = color, marker = 'D')
     plt.xlim(-1, (len(color)-1)*3+1)
-    plt.ylim(0.5, 1.5)
-    plt.axis('off')
+    plt.ylim(0.7, 1.3)
+    plt.axis('on')
 
 
     def label_node(xy, text):
@@ -194,8 +205,8 @@ def _index_generator(file_name):
             Nothing 
 
         """
-        y = xy[1] - 0.2  
-        plt.text(xy[0], y, text, ha = "center", family = 'sans-serif', size = 14, color = col)
+        y = xy[1] - 0.1  
+        plt.text(xy[0], y, text, ha = "center", family = 'sans-serif', size = 12, color = col)
 
 
     def label_number_upper(xy, text, col):
@@ -211,7 +222,7 @@ def _index_generator(file_name):
             Nothing 
 
         """
-        y = xy[1] + 0.2   
+        y = xy[1] + 0.1   
         plt.text(xy[0], y, text, ha = "center", family='sans-serif', size = 14, color = col)
         
     
